@@ -2,7 +2,7 @@ from scipy.io import readsav
 import matplotlib.dates as mdates
 import matplotlib as mpl
 
-from lofarSun.lofarJ2000xySun from j2000xy
+from lofarSun.lofarJ2000xySun import j2000xy
 import datetime
 import glob
 import os
